@@ -40,6 +40,9 @@ def deploy(
     should_forward_failures_to_opscenter,
     on_complete_url,
 ):
+    click.echo(
+        f"running in partition: {config.get_partition()} as {config.get_puppet_role_path()}{config.get_puppet_role_name()}"
+    )
     if puppet_account_id is None:
         puppet_account_id = config.get_puppet_account_id()
     executor_account_id = config.get_current_account_id()
@@ -100,8 +103,22 @@ def dry_run(f, single_account, puppet_account_id):
 @click.option(
     "--permission-boundary", default="arn:aws:iam::aws:policy/AdministratorAccess"
 )
-def bootstrap_spoke_as(puppet_account_id, iam_role_arns, permission_boundary):
-    core.bootstrap_spoke_as(puppet_account_id, iam_role_arns, permission_boundary)
+@click.option("--puppet-role-name", default="PuppetRole")
+@click.option("--puppet-role-path", default="/servicecatalog-puppet/")
+def bootstrap_spoke_as(
+    puppet_account_id,
+    iam_role_arns,
+    permission_boundary,
+    puppet_role_name,
+    puppet_role_path,
+):
+    core.bootstrap_spoke_as(
+        puppet_account_id,
+        iam_role_arns,
+        permission_boundary,
+        puppet_role_name,
+        puppet_role_path,
+    )
 
 
 @cli.command()
@@ -109,8 +126,14 @@ def bootstrap_spoke_as(puppet_account_id, iam_role_arns, permission_boundary):
 @click.option(
     "--permission-boundary", default="arn:aws:iam::aws:policy/AdministratorAccess"
 )
-def bootstrap_spoke(puppet_account_id, permission_boundary):
-    core.bootstrap_spoke(puppet_account_id, permission_boundary)
+@click.option("--puppet-role-name", default="PuppetRole")
+@click.option("--puppet-role-path", default="/servicecatalog-puppet/")
+def bootstrap_spoke(
+    puppet_account_id, permission_boundary, puppet_role_name, puppet_role_path
+):
+    core.bootstrap_spoke(
+        puppet_account_id, permission_boundary, puppet_role_name, puppet_role_path
+    )
 
 
 @cli.command()
@@ -121,11 +144,25 @@ def bootstrap_spoke(puppet_account_id, permission_boundary):
     "--permission-boundary", default="arn:aws:iam::aws:policy/AdministratorAccess"
 )
 @click.option("--num-workers", default=10)
+@click.option("--puppet-role-name", default="PuppetRole")
+@click.option("--puppet-role-path", default="/servicecatalog-puppet/")
 def bootstrap_spokes_in_ou(
-    ou_path_or_id, role_name, iam_role_arns, permission_boundary, num_workers
+    ou_path_or_id,
+    role_name,
+    iam_role_arns,
+    permission_boundary,
+    num_workers,
+    puppet_role_name,
+    puppet_role_path,
 ):
     core.bootstrap_spokes_in_ou(
-        ou_path_or_id, role_name, iam_role_arns, permission_boundary, num_workers
+        ou_path_or_id,
+        role_name,
+        iam_role_arns,
+        permission_boundary,
+        num_workers,
+        puppet_role_name,
+        puppet_role_path,
     )
 
 
@@ -171,6 +208,8 @@ def bootstrap_spokes_in_ou(
 @click.option("--branch")
 @click.option("--poll-for-source-changes")
 @click.option("--webhook-secret")
+@click.option("--puppet-role-name", default="PuppetRole")
+@click.option("--puppet-role-path", default="/servicecatalog-puppet/")
 def bootstrap_branch(
     branch_to_bootstrap,
     with_manual_approvals,
@@ -189,6 +228,8 @@ def bootstrap_branch(
     branch,
     poll_for_source_changes,
     webhook_secret,
+    puppet_role_name,
+    puppet_role_path,
 ):
     puppet_account_id = config.get_puppet_account_id()
 
@@ -210,6 +251,8 @@ def bootstrap_branch(
             branch_name,
             poll_for_source_changes,
             webhook_secret,
+            puppet_role_name,
+            puppet_role_path,
         )
     elif source_provider == "GitHub":
         core.bootstrap_branch(
@@ -280,6 +323,8 @@ def bootstrap_branch(
 @click.option("--branch")
 @click.option("--poll-for-source-changes")
 @click.option("--webhook-secret")
+@click.option("--puppet-role-name", default="PuppetRole")
+@click.option("--puppet-role-path", default="/servicecatalog-puppet/")
 def bootstrap(
     with_manual_approvals,
     puppet_code_pipeline_role_permission_boundary,
@@ -298,6 +343,8 @@ def bootstrap(
     branch,
     poll_for_source_changes,
     webhook_secret,
+    puppet_role_name,
+    puppet_role_path,
 ):
     puppet_account_id = config.get_puppet_account_id()
     if source_provider == "CodeCommit":
@@ -318,6 +365,8 @@ def bootstrap(
             branch_name,
             poll_for_source_changes,
             webhook_secret,
+            puppet_role_name,
+            puppet_role_path,
         )
     elif source_provider == "GitHub":
         core.bootstrap(
@@ -337,6 +386,8 @@ def bootstrap(
             branch,
             poll_for_source_changes,
             webhook_secret,
+            puppet_role_name,
+            puppet_role_path,
         )
     else:
         raise Exception(f"Unsupported source provider: {source_provider}")
@@ -465,6 +516,13 @@ def set_config_value(name, value):
     core.set_config_value(name, value)
 
 
+@cli.command()
+@click.argument("name")
+@click.argument("value")
+def set_named_config_value(name, value):
+    core.set_named_config_value(name, value)
+
+
 @cli.command()
 @click.argument("execution_id")
 @click.option("--puppet-account-id", default=None)
@@ -494,6 +552,7 @@ def release_spoke(puppet_account_id):
 @click.argument("iam_role_arns", nargs=-1)
 def wait_for_code_build_in(iam_role_arns):
     core.wait_for_code_build_in(iam_role_arns)
+    core.wait_for_cloudformation_in(iam_role_arns)
     click.echo("AWS CodeBuild is available")
 
 
