@@ -51,3 +51,18 @@ EXECUTION_SPOKE_CODEBUILD_PROJECT_NAME = "servicecatalog-puppet-deploy-in-spoke"
 SHARING_MODE_ACCOUNT = "ACCOUNT"
 SHARING_MODE_AWS_ORGANIZATIONS = "AWS_ORGANIZATIONS"
 SHARING_MODE_DEFAULT = SHARING_MODE_ACCOUNT
+
+PARTITION_DEFAULT = "aws"
+PARTITION_ENVIRONMENTAL_VARIABLE_NAME = "PARTITION"
+PARTITION_SSM_PARAMETER_VARIABLE_NAME = "/servicecatalog-puppet/partition"
+
+PUPPET_ROLE_NAME_DEFAULT = "PuppetRole"
+PUPPET_ROLE_NAME_ENVIRONMENTAL_VARIABLE_NAME = "PUPPET_ROLE_NAME"
+PUPPET_ROLE_NAME_SSM_PARAMETER_VARIABLE_NAME = "/servicecatalog-puppet/puppet-role/name"
+
+PUPPET_ROLE_PATH_DEFAULT = "/servicecatalog-puppet/"
+PUPPET_ROLE_PATH_ENVIRONMENTAL_VARIABLE_NAME = "PUPPET_ROLE_PATH"
+PUPPET_ROLE_PATH_SSM_PARAMETER_VARIABLE_NAME = "/servicecatalog-puppet/puppet-role/path"
+
+
+DEPLOY_ENVIRONMENT_COMPUTE_TYPE_DEFAULT = "BUILD_GENERAL1_SMALL"
